lilypondfiletools.MIDIBlock
===========================

.. abjad-lineage:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock

.. autoclass:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.append
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.count
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.extend
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.index
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.insert
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.pop
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.remove
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.reverse
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.sort
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__add__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__contains__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__delitem__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__delslice__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__eq__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__format__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__ge__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__getitem__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__getslice__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__gt__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__iadd__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__imul__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__iter__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__le__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__len__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__lt__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__mul__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__ne__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__repr__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__reversed__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__rmul__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__setitem__
      ~abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.__setslice__
   :noindex:
